This project follows the [skeleton](https://blog.jaraco.com/skeleton); please read for context on development.

Before committing, ensure .git/info/exclude is populated from jaraco/dotfiles .gitignore_global so that generated artifacts are never staged.
